package mytv.persistence;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.time.Duration;
import java.util.SortedSet;
import java.util.StringTokenizer;
import java.util.TreeSet;

import mytv.model.Programme;

public class MyProgrammeReader implements ProgrammeReader {

	public MyProgrammeReader() {
	}

	@Override
	public SortedSet<Programme> readAll(Reader reader) throws IOException,
			BadFileFormatException {
		BufferedReader r = new BufferedReader(reader);
		
		TreeSet<Programme> programmes = new TreeSet<>();
		
		String line;
		while ((line = r.readLine()) != null && !line.trim().isEmpty()) {
			StringTokenizer tok = new StringTokenizer(line, "\t");
			
			String title = tok.nextToken();
			if (title.trim().isEmpty())
				throw new BadFileFormatException("title token is empty");
			
			String hh = tok.nextToken("\t:");
			if (hh.trim().isEmpty())
				throw new BadFileFormatException("hours token is empty");
			int hours = parseInt(hh);
			
			String mm = tok.nextToken("\t:");
			if (mm.trim().isEmpty())
				throw new BadFileFormatException("minutes token is empty");
			int mins = parseInt(mm);
			
			Duration duration = Duration.ofHours(hours).plusMinutes(mins);
			
			programmes.add(new Programme(title, duration));
		}
		
		return programmes;
	}
		
	private int parseInt(String s) throws BadFileFormatException {
		try {
			return Integer.parseInt(s);
		}
		catch (NumberFormatException e)	{
			throw new BadFileFormatException("Expected int", e);
		}
	}

}
